/*
 *
 *	ST-LOW Library
 *	(c) 2010 by Simon Sunnyboy / Paradize <marndt@asmsoftware.de>
 *	http://paradize.atari.org/
 *
 *	routines to handle loading of picture files into the
 *  STLowPicture data structure
 *
 *	This library is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU Lesser General Public
 *	License as published by the Free Software Foundation; either
 *	version 2.1 of the License, or (at your option) any later version.
 *
 *	This library is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *	Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with this library; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */

#include "src\stlow.h"
#include <tos.h>
#include <falcon.h>
#include <stdio.h>
#include <stdlib.h>

/* variables */

/* prototypes of lib internal functions */

/* functions */
void STLOW_LoadDegas(char *filename, STLowPicture *picture)
{
	FILE *fp;
	fp = fopen(filename, "rb");
	if(fp == 0)
	{
		picture->rez = PICTURE_UNDEFINED; 
	}
	else
	{
		fseek(fp, 0, SEEK_SET);
		if(fread((void *)picture, sizeof(STLowPicture), 1, fp) < 1)
		{
			/* maybe a PC1 or PC2 file? try unpacking the packed data */
		}
	}
	fclose(fp);
	
	return;
}

void STLOW_LoadDegasCompressed(char *filename, STLowPicture *picture)
{
	FILE *fp;
	void *tempspace;
	long bytes;

	fp = fopen(filename, "rb");
	if(fp == 0)
	{
		picture->rez = PICTURE_UNDEFINED; 
	}
	else
	{
		fseek(fp, 0,SEEK_END);   		
		if(ftell(fp) > 32033)
		{
			/* err not a compressed Degas picture? */
			STLOW_LoadDegas(filename,picture);
		}
		else
		{
			fseek(fp, 0, SEEK_SET);
			tempspace = malloc(33000);
			if(tempspace != NULL)
			{
				bytes = fread(tempspace, sizeof(unsigned char), 33000, fp);
				STLOW_DepackPC1(tempspace, picture); 
			}
			else
			{
				/* malloc for temp buffer failed */
				picture->rez = PICTURE_UNDEFINED;
			}
			free(tempspace);
		
		}
	}
	fclose(fp);
	
	return;
}

void STLOW_LoadNeochrome(char *filename, STLowPicture *picture)
{
	FILE *fp;
	fp = fopen(filename, "rb");
	if(fp == 0)
	{
		picture->rez = PICTURE_UNDEFINED; 
	}
	else
	{
		fseek(fp, 0,SEEK_END);   		
		if(ftell(fp) != 32128)
		{
			/* no NEOCHROME file */
			picture->rez = PICTURE_UNDEFINED; 			
		}
		else
		{
			rewind(fp);
			fseek(fp, 4, SEEK_SET);
			fread(picture->palette, sizeof(unsigned char), 32, fp);
			fseek(fp, 128, SEEK_SET);
			fread(picture->data, sizeof(unsigned char), 32000, fp);
			picture->rez = 0;
		}
	}
	fclose(fp);
	
	return;
}

void STLOW_ShowPicture(STLowPicture *pic, void *dest)
{
	STLOW_SetPalette(pic->palette);
	STLOW_CopyScreen(pic->data,dest);
	return;
}
