/*
 *
 *	ST-LOW Library
 *	(c) 2010 by Simon Sunnyboy / Paradize <marndt@asmsoftware.de>
 *	http://paradize.atari.org/
 *
 *	set ST-LOW or ST-MED screen mode, independant of machine
 *  and allow to return properly
 *
 *	This library is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU Lesser General Public
 *	License as published by the Free Software Foundation; either
 *	version 2.1 of the License, or (at your option) any later version.
 *
 *	This library is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *	Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with this library; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */

#include "src\stlow.h"
#include <tos.h>
#include <falcon.h>

/* variables */
unsigned short old_palette[16];
void *oldlog, *oldphy;
short oldrez;
unsigned char falcon = 0;
/* prototypes of lib internal functions */
void SetSTMode(STLowMode);
void SetFalconMode(STLowMode);
short STLOW_Vsetmode(short);

/* functions */
void STLOW_ShowScreen(void *newscreen)
{
	Setscreen(-1,newscreen,-1);
	return;
}

STLowMode STLOW_SetSTMode(unsigned long mchcookie, STLowMode videomode)
{
	STLowMode retvalue;

	falcon = 0;
	
	if((videomode != ST_LOW)&&(videomode != ST_MED))
	{
		return(MODE_ERROR);
	}
	
	switch((mchcookie & 0xFFFF0000))
	{
	case 0x00000:
	case 0x10000:
		/* STFM + STE */
		if(Getrez() == 2)
		{
			retvalue = MODE_SM124;
			break;
		}
		/* fallthrough and use XBIOS 5 like on the TT */
	case 0x20000:
		/* TT */
		SetSTMode(videomode);
		retvalue = videomode;
		break;
	case 0x30000:
		/* Falcon */
		SetFalconMode(videomode);
		retvalue = videomode;
		break;
	default:
		/* default is a not supported "Atari" */
		retvalue = MODE_ERROR;
		break;
	}
	
	return(retvalue);
}

void STLOW_RestoreVideoMode()
{
	if(!falcon)
	{
		Setscreen(oldlog,oldphy,oldrez);
	}
	else
	{
		Setscreen(oldlog,oldphy,-1);
		STLOW_Vsetmode(oldrez);
	}
	STLOW_SetPalette(old_palette);
	return;
}

void SetSTMode(STLowMode mode)
{
	oldrez = Getrez();
	oldlog = Logbase();
	oldphy = Physbase();
	
	if(mode == ST_LOW)
	{
		Setscreen(-1,-1,(unsigned short) 0);
	}
	else if(mode == ST_MED)
	{
		Setscreen(-1,-1,(unsigned short) 1);
	}
	STLOW_GetPalette(old_palette);
	return;
}

void SetFalconMode(STLowMode mode)
{
	falcon = 1;
	oldrez = STLOW_Vsetmode(-1);
	oldlog = Logbase();
	oldphy = Physbase();
	
	if(mode == ST_LOW)
	{
		STLOW_Vsetmode(434);
	}
	else if(mode == ST_MED)
	{
		STLOW_Vsetmode(424);
	}
	STLOW_GetPalette(old_palette);
	return;
}
